@@ -1,7 +1,7 @@
 package DBIx::Custom;
 use Object::Simple -base;
 
-our $VERSION = '0.1734';
+our $VERSION = '0.1735';
 use 5.008001;
 
 use Carp 'croak';
@@ -123,6 +123,10 @@ sub assign_clause {
     my ($self, $param, $opts) = @_;
     
     my $wrap = $opts->{wrap} || {};
+
+    my $qp = $self->_q('');
+    my $q = substr($qp, 0, 1) || '';
+    my $p = substr($qp, 1, 1) || '';
     
     # Create set tag
     my @params;
@@ -130,8 +134,8 @@ sub assign_clause {
     for my $column (sort keys %$param) {
         croak qq{"$column" is not safety column name } . _subname
           unless $column =~ /^[$safety\.]+$/;
-        my $column_quote = $self->_q($column);
-        $column_quote =~ s/\./$self->_q(".")/e;
+        my $column_quote = "$q$column$p";
+        $column_quote =~ s/\./$p.$q/;
         my $func = $wrap->{$column} || sub { $_[0] };
         push @params,
           ref $param->{$column} eq 'SCALAR' ? "$column_quote = " . ${$param->{$column}}
@@ -363,10 +367,15 @@ sub execute {
     $sql .= $opt{append} if defined $opt{append} && !ref $sql;
     
     # Query
-    my $query = ref $sql ? $sql
-      : $self->_create_query($sql,$opt{after_build_sql} || $opt{sqlfilter},
-          $opt{reuse_sth});
-    
+    my $query;
+    if (ref $sql) { $query = $sql }
+    else {
+        $query = $opt{reuse}->{$sql} if $opt{reuse};
+        $query = $self->_create_query($sql,$opt{after_build_sql} || $opt{sqlfilter})
+          unless $query;
+        $opt{reuse}->{$sql} = $query if $opt{reuse};
+    }
+        
     # Save query
     $self->last_sql($query->sql);
 
@@ -1075,11 +1084,15 @@ sub values_clause {
     my $safety = $self->safety_character;
     my @columns;
     my @placeholders;
+    my $qp = $self->_q('');
+    my $q = substr($qp, 0, 1) || '';
+    my $p = substr($qp, 1, 1) || '';
+    
     for my $column (sort keys %$param) {
         croak qq{"$column" is not safety column name } . _subname
           unless $column =~ /^[$safety\.]+$/;
-        my $column_quote = $self->_q($column);
-        $column_quote =~ s/\./$self->_q(".")/e;
+        my $column_quote = "$q$column$p";
+        $column_quote =~ s/\./$p.$q/;
         push @columns, $column_quote;
         
         my $func = $wrap->{$column} || sub { $_[0] };
@@ -1096,7 +1109,7 @@ sub where { DBIx::Custom::Where->new(dbi => shift, @_) }
 
 sub _create_query {
     
-    my ($self, $source, $after_build_sql, $reuse_sth) = @_;
+    my ($self, $source, $after_build_sql) = @_;
     
     # Cache
     my $cache = $self->cache;
@@ -1153,9 +1166,7 @@ sub _create_query {
     
     # Prepare statement handle
     my $sth;
-    $sth = $reuse_sth->{$query->{sql}} if $reuse_sth;
-    eval { $sth = $self->dbh->prepare($query->{sql}) } unless $sth;
-    $reuse_sth->{$query->{sql}} = $sth if $reuse_sth;
+    eval { $sth = $self->dbh->prepare($query->{sql}) };
     
     if ($@) {
         $self->_croak($@, qq{. Following SQL is executed.\n}
@@ -2581,17 +2592,17 @@ Table alias. Key is real table name, value is alias table name.
 If you set C<table_alias>, you can enable C<into1> and C<into2> type rule
 on alias table name.
 
-=item C<reuse_sth EXPERIMENTAL>
+=item C<reuse EXPERIMENTAL>
     
-    reuse_sth => $has_ref
+    reuse_query => $has_ref
 
-Reuse statament handle if the hash reference variable is set.
+Reuse query object if the hash reference variable is set.
     
-    my $sth = {};
-    $dbi->execute($sql, $param, sth => $sth);
+    my $queries = {};
+    $dbi->execute($sql, $param, reuse => $queries);
 
-This will improved performance when same sql is executed repeatedly
-because generally creating statement handle is slow.
+This will improved performance when you want to execute same query repeatedly
+because generally creating query object is slow.
 
 =item C<type_rule_off>
 
